@@ -5,7 +5,7 @@ import sys
 import glob
 import subprocess
 
-re_ignore = re.compile(r'(^_|\.(dpkg-(old|dist|new|tmp)|example)$)')
+re_ignore = re.compile(r'(^_|\.(dpkg-(old|dist|new|tmp)|example)$|\.pyc$)')
 
 def main(conf_dir, pid_dir, log_dir, action):
     files = glob.glob(os.path.join(conf_dir, '*'))
@@ -13,40 +13,52 @@ def main(conf_dir, pid_dir, log_dir, action):
     if not os.path.exists(pid_dir):
         os.makedirs(pid_dir)
 
+    # Update Python path so configurations can extend each other.
+    sys.path.append(conf_dir)
+
     for filename in sorted(files):
-        if re_ignore.search(filename):
+        if re_ignore.search(os.path.basename(filename)):
             continue
 
         if sys.version_info > (2, 6):
             # We are using a version that understands PYTHONDONTWRITEBYTECODE
             # so it is safe to use imp.load_source here - otherwise we create
             # "pyc"-like files in /etc/gunicorn.d which we then try and parse.
-            CONFIG = imp.load_source(filename, filename).CONFIG
+            module = imp.load_source(filename, filename)
+            CONFIG = getattr(module, 'CONFIG', None)
         else:
-            exec open(filename).read()
+            module = {}
+            execfile(filename, module)
+            CONFIG = module.get('CONFIG')
+
+        if not CONFIG:
+            continue
 
         config = Config(filename, pid_dir, log_dir, CONFIG)
 
-        if action in ('start', 'stop', 'reload'):
-            config.print_name()
-            getattr(config, action)()
-        else:
+        if action not in ('start', 'stop', 'reload'):
             raise ValueError("Invalid action: %s" % action)
 
+        config.print_name()
+        getattr(config, action)()
+
     # Kill any renaming pidfiles to prevent the case where we remove or
     # renaming a configuration and it doesn't get stopped or restarted.
     if action == 'stop':
         for pidfile in glob.glob(os.path.join(pid_dir, '*.pid')):
-            if subprocess.call((
+            subprocess.call((
                 'start-stop-daemon',
                 '--stop',
                 '--oknodo',
                 '--retry', '1',
                 '--quiet',
                 '--pidfile', pidfile,
-            )):
-                # We killed the process
+            ))
+
+            try:
                 os.unlink(pidfile)
+            except OSError:
+                pass
 
     return 0
 
@@ -129,7 +141,6 @@ class Config(dict):
             '--signal', 'HUP',
             '--oknodo',
             '--quiet',
-            '--retry', '10',
             '--pidfile', self.pidfile(),
         ))
 
